package com.kuyuntech.cofarcooking.device.sdk.devmode.core;

import com.kuyuntech.cofarcooking.device.sdk.constant.core.DevStatus;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorDirections;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.WorkModes;
import com.kuyuntech.cofarcooking.device.sdk.eventbus.core.DevInfo;
import com.kuyuntech.cofarcooking.device.sdk.util.core.CofarSDK;

import java.util.TimerTask;

public class SlowCooking033F extends BaseDevMode{

    private Long currentSec = 0l;

    private Thread thread;

    private boolean pasue = false;

    private boolean stop = false;

    private boolean autoPasue = false;

    private  byte isMotorGear = 0;
    private  boolean isMotorType = false;

    public SlowCooking033F(){

        this.setMode(WorkModes.SLOW_COOKING);


        //时间
        this.setMinTime(0);
        this.setMaxTime(480 * 60);
        this.setDefaultTime(60 * 60);
        this.setTimeChange(true);

        //电机
        this.setDefaultMotorGear(1);
        this.setMaxMotorGear(1);
        this.setMinMotorGear(1);
        this.setMotorGearChange(false);
        this.setMotorDirectionChange(false);
        this.setMotorDirection(MotorDirections.REVERSE);

        //温度
        this.setDefaultTemp(90);
        this.setMinTemp(37);
        this.setMaxTemp(95);

        this.setDiyCountDown(true);

    }

    @Override
    public void start() {
        currentSec = 0L;
        isMotorGear = CofarSDK.devInfo().getMotorGear();
        CofarSDK.startNative();
        this.stop = false;

    }


    @Override
    public void onCountDown(TimerTask timer) {

        if (!pasue && DevStatus.PAUSE == CofarSDK.devInfo().getStatus()) {
            if (!autoPasue) {
                return;
            }
        }

        if (pasue) {
            return;
        }

        DevInfo devInfo = CofarSDK.devInfo();


        if (devInfo.getRemainTime() <= 0 && devInfo.getMode().isCountDown()) {
            CofarSDK.stop();
            timer.cancel();
            return;
        }


        if (stop) {
            CofarSDK.stop();
            timer.cancel();
            return;
        }

        devInfo.setRemainTime((short) (devInfo.getRemainTime() - 1));


        if (((currentSec / 5) % 6) == 1) {
            autoPasue=true;
            if (isMotorType){
                CofarSDK.cfgMotorGearNative((byte)0);
                isMotorType = false;
            }
        }

        if (((currentSec / 5) % 6) == 0) {
            autoPasue=false;
            if (!isMotorType){
                CofarSDK.cfgMotorGearNative(isMotorGear);
                isMotorType = true;
            }
        }


        currentSec++;

    }

    @Override
    public void pause() {
        this.pasue = true;
        CofarSDK.pauseNatvie();
    }

    @Override
    public void resume() {
        this.pasue = false;
        CofarSDK.resumeNavtive();

    }

    @Override
    public void stop() {
        this.stop = true;
        CofarSDK.stopNative();
        CofarSDK.cfgMotorGearNative((byte) getDefaultMotorGear());
        super.stop();
    }




}
